@@ -146,7 +146,7 @@ void init_coz(void) {
   shared_ptr<line> fixed_line;
   if(fixed_line_name != "") {
     fixed_line = memory_map::get_instance().find_line(fixed_line_name);
-    PREFER(fixed_line) << "Fixed line \"" << fixed_line_name << "\" was not found.";
+    REQUIRE(fixed_line) << "Fixed line \"" << fixed_line_name << "\" was not found.";
   }
 
   // Create an end-to-end progress point and register it if running in
@@ -363,18 +363,21 @@ extern "C" {
   void __attribute__((noreturn)) exit(int status) throw() {
     profiler::get_instance().shutdown();
     real::exit(status);
+    abort(); // Silence g++ warning about noreturn
   }
 
   /// Run shutdown before exiting
   void __attribute__((noreturn)) _exit(int status) {
     profiler::get_instance().shutdown();
   	real::_exit(status);
+    abort(); // Silence g++ warning about noreturn
   }
 
   /// Run shutdown before exiting
   void __attribute__((noreturn)) _Exit(int status) throw() {
     profiler::get_instance().shutdown();
     real::_Exit(status);
+    abort(); // Silence g++ warning about noreturn
   }
 
   /// Don't allow programs to set signal handlers for coz's required signals
